@@ -140,13 +140,10 @@ OC.L10N.register(
     "Calendar settings" : "Configuración del calendariu",
     "No reminder" : "Nun hai nengún recordatoriu",
     "Failed to save default calendar" : "Nun se pue guardar el calendariu predetermináu",
-    "CalDAV link copied to clipboard." : "L'enllaz CalDAV copióse nel cartafueyu.",
-    "CalDAV link could not be copied to clipboard." : "L'enllaz CalDAV nun se pudo copiar nel cartafueyu.",
     "General" : "Xeneral",
-    "Copy iOS/macOS CalDAV address" : "Copiar la direición CalDAV d'iOS/macOS",
     "Appearance" : "Aspeutu",
     "Default reminder" : "Recordatoriu predetermináu",
-    "Keyboard shortcuts" : "Atayos del tecláu",
+    "Files" : "Ficheros",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minutu","{duration} minutos"],
     "0 minutes" : "0 minutos",
     "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} hores"],
@@ -212,7 +209,6 @@ OC.L10N.register(
     "Decline" : "Refugar",
     "Tentative" : "Provisional",
     "No attendees yet" : "Nun hai nengún asistente",
-    "Error creating Talk room" : "Hebo un error al crear la sala de Talk",
     "Attendees" : "Asistentes",
     "Remove group" : "Quitar el grupu",
     "_%n member_::_%n members_" : ["%n miembru","%n miembros"],
@@ -290,6 +286,8 @@ OC.L10N.register(
     "User not found" : "Nun s'atopó l'usuariu",
     "Hidden" : "Anubrióse",
     "Calendar name …" : "Nome del calendariu…",
+    "CalDAV link copied to clipboard." : "L'enllaz CalDAV copióse nel cartafueyu.",
+    "CalDAV link could not be copied to clipboard." : "L'enllaz CalDAV nun se pudo copiar nel cartafueyu.",
     "Enable birthday calendar" : "Activar el calendariu de los cumpleaños",
     "Show tasks in calendar" : "Amosar les xeres nel calendariu",
     "Enable simplified editor" : "Activar l'editor simplificáu",
@@ -297,8 +295,10 @@ OC.L10N.register(
     "Show weekends" : "Amosar les fines de selmana",
     "Show week numbers" : "Amosar los númberos de selmana",
     "Copy primary CalDAV address" : "Copiar la direición CalDAV primaria",
+    "Copy iOS/macOS CalDAV address" : "Copiar la direición CalDAV d'iOS/macOS",
     "Personal availability settings" : "Configuración de la disponibilidá personal",
     "Show keyboard shortcuts" : "Amosar los atayos del tecáu",
+    "Error creating Talk room" : "Hebo un error al crear la sala de Talk",
     "_%n more guest_::_%n more guests_" : ["%n convidáu más","%n convidaos más"]
 },
 "nplurals=2; plural=(n != 1);");
