@@ -177,14 +177,11 @@ OC.L10N.register(
     "or" : "یا",
     "Calendar settings" : "تنظیمات تقویم",
     "No reminder" : "No reminder",
-    "CalDAV link copied to clipboard." : "پیوند CalDAV در کلیپ بورد کپی شد.",
-    "CalDAV link could not be copied to clipboard." : "پیوند CalDAV در کلیپ بورد قابل کپی نیست.",
     "General" : "عمومی",
-    "Copy iOS/macOS CalDAV address" : "آدرس CalDAV iOS / macOS را کپی کنید",
     "Appearance" : "ظاهر",
     "Editing" : "ویرایش کردن",
     "Default reminder" : "Default reminder",
-    "Keyboard shortcuts" : "میان‌برهای صفحه‌کلید",
+    "Files" : "پرونده‌ها",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minute","{duration} minutes"],
     "0 minutes" : "0 minutes",
     "_{duration} hour_::_{duration} hours_" : ["{duration} hour","{duration} hours"],
@@ -291,9 +288,6 @@ OC.L10N.register(
     "Decline" : "کاهش می یابد",
     "Tentative" : "آزمایشی",
     "No attendees yet" : "هنوز هیچ حضوری وجود ندارد",
-    "Successfully appended link to talk room to location." : "Successfully appended link to talk room to location.",
-    "Successfully appended link to talk room to description." : "پیوند موفقیت آمیز پیوند به اتاق گفتگو به توضیحات.",
-    "Error creating Talk room" : "خطا در ایجاد اتاق گفتگو",
     "Attendees" : "شرکت کنندگان",
     "Remove group" : "برداشتن گروه",
     "Remove attendee" : "شرکت کننده را حذف کنید",
@@ -376,6 +370,7 @@ OC.L10N.register(
     "By {authors}" : "By {authors}",
     "Subscribed" : "Subscribed",
     "Subscribe" : "اشتراک گذاری",
+    "Select a date" : "تاریخ را انتخاب کنید",
     "Select slot" : "Select slot",
     "No slots available" : "No slots available",
     "The slot for your appointment has been confirmed" : "The slot for your appointment has been confirmed",
@@ -504,6 +499,8 @@ OC.L10N.register(
     "Default attachments location" : "Default attachments location",
     "Automatic ({detected})" : "خودکار ({شناسایی})",
     "Shortcut overview" : "Shortcut overview",
+    "CalDAV link copied to clipboard." : "پیوند CalDAV در کلیپ بورد کپی شد.",
+    "CalDAV link could not be copied to clipboard." : "پیوند CalDAV در کلیپ بورد قابل کپی نیست.",
     "Enable birthday calendar" : "تقویم تولد را فعال کنید",
     "Show tasks in calendar" : "نمایش وظایف در تقویم",
     "Enable simplified editor" : "ویرایشگر ساده شده را فعال کنید",
@@ -512,8 +509,12 @@ OC.L10N.register(
     "Show week numbers" : "نمایش شماره های هفته",
     "Time increments" : "Time increments",
     "Copy primary CalDAV address" : "آدرس اصلی CalDAV را کپی کنید",
+    "Copy iOS/macOS CalDAV address" : "آدرس CalDAV iOS / macOS را کپی کنید",
     "Personal availability settings" : "Personal availability settings",
     "Show keyboard shortcuts" : "Show keyboard shortcuts",
+    "Successfully appended link to talk room to location." : "Successfully appended link to talk room to location.",
+    "Successfully appended link to talk room to description." : "پیوند موفقیت آمیز پیوند به اتاق گفتگو به توضیحات.",
+    "Error creating Talk room" : "خطا در ایجاد اتاق گفتگو",
     "The visibility of this event in shared calendars." : "قابلیت مشاهده این رویداد در تقویمهای مشترک."
 },
 "nplurals=2; plural=(n > 1);");
