@@ -132,12 +132,10 @@ OC.L10N.register(
     "Deleting share link …" : "공유링크 삭제 …",
     "An error occurred while unsharing the calendar." : "달력 공유 해제 중 오류 발생",
     "An error occurred, unable to change the permission of the share." : "오류가 발생하여 공유 권한을 변경할 수 없습니다.",
-    "can edit" : "편집 가능",
     "Unshare with {displayName}" : "{displayName}과 공유 중단",
     "Share with users or groups" : "사용자 및 그룹과 공유",
     "No users or groups" : "사용자나 그룹 없음",
     "Failed to save calendar name and color" : "달력 이름 및 색상 저장 실패",
-    "Calendar name …" : "달력 이름 ...",
     "Share calendar" : "달력 공유",
     "Unshare from me" : "나의 공유 해제",
     "Save" : "저장",
@@ -153,7 +151,7 @@ OC.L10N.register(
     "Invalid location selected" : "잘못된 위치가 선택됨",
     "Attachments folder successfully saved." : "첨부파일 폴더가 성공적으로 저장됨.",
     "Error on saving attachments folder." : "첨부파일 폴더 설정 저장 중 오류 발생",
-    "Default attachments location" : "기본 첨부파일 위치",
+    "Attachments folder" : "첨부 파일 폴더",
     "{filename} could not be parsed" : "{filename} 분석할 수 없음",
     "No valid files found, aborting import" : "올바른 파일을 발견할 수 없음, 가져오기 취소",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["%n개의 일정을 성공적으로 가져옴"],
@@ -182,19 +180,11 @@ OC.L10N.register(
     "or" : "또는",
     "Calendar settings" : "달력 설정",
     "No reminder" : "알림 없음",
-    "CalDAV link copied to clipboard." : "CalDAV 링크를 클립보드에 복사했습니다.",
-    "CalDAV link could not be copied to clipboard." : "CalDAV 링크를 클립보드에 복사할 수 없습니다.",
     "General" : "일반",
-    "Personal availability settings" : "개인별 시간 조율 설정",
-    "Copy primary CalDAV address" : "주 CalDAV 주소 복사하기",
-    "Copy iOS/macOS CalDAV address" : "iOS/macOS CalDAV 주소 복사하기",
-    "Enable birthday calendar" : "생일 달력 활성화",
-    "Show tasks in calendar" : "달력에 작업 보이기",
-    "Show weekends" : "공휴일 보기",
-    "Show week numbers" : "주 번호 보이기",
+    "Appearance" : "외형",
     "Editing" : "글 수정",
     "Default reminder" : "기본 알림",
-    "Keyboard shortcuts" : "키보드 단축키",
+    "Files" : "파일",
     "Appointment schedule successfully created" : "약속 일정이 성공적으로 생성되었습니다",
     "Appointment schedule successfully updated" : "약속 일정이 성공적으로 갱신되었습니다",
     "_{duration} minute_::_{duration} minutes_" : ["{duration}분"],
@@ -308,9 +298,6 @@ OC.L10N.register(
     "Decline" : "거절",
     "Tentative" : "예정됨",
     "No attendees yet" : "아직 참석자가 없습니다.",
-    "Successfully appended link to talk room to location." : "위치에 대화방 링크를 성공적으로 추가함",
-    "Successfully appended link to talk room to description." : "설명에 대화방 링크를 성공적으로 추가함",
-    "Error creating Talk room" : "대화방 생성 오류",
     "Attendees" : "참석자",
     "Remove group" : "그룹 지우기",
     "Remove attendee" : "참석자 삭제",
@@ -493,7 +480,6 @@ OC.L10N.register(
     "When shared show full event" : "전체 일정 공유",
     "When shared show only busy" : "바쁨/한가함만 공유",
     "When shared hide this event" : "일정 공유하지 않음",
-    "The visibility of this event in shared calendars." : "공유 달력에서 이 일정의 표시 여부",
     "Add a location" : "위치 추가",
     "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "설명을 입력하세요\n\n- 회의 목적\n- 안건 목록\n- 참석자들이 준비해야 할 것들",
     "Status" : "상태",
@@ -517,11 +503,27 @@ OC.L10N.register(
     "Appointment not found" : "약속을 찾을 수 없음",
     "User not found" : "사용자를 찾을 수 없음",
     "Hidden" : "숨겨짐",
+    "can edit" : "편집 가능",
+    "Calendar name …" : "달력 이름 ...",
+    "Default attachments location" : "기본 첨부파일 위치",
     "Automatic ({detected})" : "자동 ({detected})",
     "Shortcut overview" : "바로가기 개요",
+    "CalDAV link copied to clipboard." : "CalDAV 링크를 클립보드에 복사했습니다.",
+    "CalDAV link could not be copied to clipboard." : "CalDAV 링크를 클립보드에 복사할 수 없습니다.",
+    "Enable birthday calendar" : "생일 달력 활성화",
+    "Show tasks in calendar" : "달력에 작업 보이기",
     "Enable simplified editor" : "간편한 편집기 활성화",
     "Limit the number of events displayed in the monthly view" : "월간 보기에서 표시되는 일정의 수 제한",
+    "Show weekends" : "공휴일 보기",
+    "Show week numbers" : "주 번호 보이기",
     "Time increments" : "시간 단위",
-    "Show keyboard shortcuts" : "키보드 단축키 표시"
+    "Copy primary CalDAV address" : "주 CalDAV 주소 복사하기",
+    "Copy iOS/macOS CalDAV address" : "iOS/macOS CalDAV 주소 복사하기",
+    "Personal availability settings" : "개인별 시간 조율 설정",
+    "Show keyboard shortcuts" : "키보드 단축키 표시",
+    "Successfully appended link to talk room to location." : "위치에 대화방 링크를 성공적으로 추가함",
+    "Successfully appended link to talk room to description." : "설명에 대화방 링크를 성공적으로 추가함",
+    "Error creating Talk room" : "대화방 생성 오류",
+    "The visibility of this event in shared calendars." : "공유 달력에서 이 일정의 표시 여부"
 },
 "nplurals=1; plural=0;");
