@@ -14,11 +14,12 @@ OC.L10N.register(
     "Delete permanently" : "Obriši zauvek",
     "Copy internal link" : "Kopiraj internu vezu",
     "Share link" : "Veza deljenja",
-    "can edit" : "može da menja",
     "Save" : "Save",
     "Filename" : "Ime fajla",
     "Cancel" : "Cancel",
     "List view" : "Prikaz liste",
+    "Appearance" : "Izgled",
+    "Files" : "Fajlovi",
     "Update" : "Ažuriraj",
     "Description" : "Opis",
     "Add" : "Dodaj",
@@ -37,11 +38,13 @@ OC.L10N.register(
     "never" : "never",
     "Yes" : "Da",
     "No" : "Ne",
+    "None" : "Ništa",
     "Close" : "Zatvori",
     "Participants" : "Učesnici",
     "Daily" : "дневно",
     "Weekly" : "недељно",
     "second" : "sekund",
-    "Other" : "Ostali"
+    "Other" : "Ostali",
+    "can edit" : "može da menja"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
