@@ -16,7 +16,7 @@ class ClientException extends Exception {
 	/** @var int|null */
 	private $httpCode;
 
-	public function __construct($message = "",
+	public function __construct($message = '',
 		$code = 0,
 		?Throwable $previous = null,
 		?int $httpCode = null) {
